bux 0.9.0

Embedded micro-VM sandbox for running AI agents
docs.rs failed to build bux-0.9.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: bux-0.6.0

Bux

Embedded micro-VM sandbox for running AI agents, powered by libkrun with KVM (Linux) or Hypervisor.framework (macOS).


A QuantX open-source project.

Code is law. We write both.